@@ -1,6 +1,6 @@
 # --
 # Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
-# Copyright (C) 2021 Znuny GmbH, https://znuny.org/
+# Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -30,7 +30,10 @@ sub new {
 sub Run {
     my ( $Self, %Param ) = @_;
 
-    my $ParamObject = $Kernel::OM->Get('Kernel::System::Web::Request');
+    my $ParamObject            = $Kernel::OM->Get('Kernel::System::Web::Request');
+    my $LayoutObject           = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
+    my $EntityObject           = $Kernel::OM->Get('Kernel::System::ProcessManagement::DB::Entity');
+    my $TransitionActionObject = $Kernel::OM->Get('Kernel::System::ProcessManagement::DB::TransitionAction');
 
     $Self->{Subaction} = $ParamObject->GetParam( Param => 'Subaction' ) || '';
 
@@ -46,11 +49,6 @@ sub Run {
         Data => $SessionData{ProcessManagementScreensPath}
     );
 
-    # get needed objects
-    my $LayoutObject           = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
-    my $EntityObject           = $Kernel::OM->Get('Kernel::System::ProcessManagement::DB::Entity');
-    my $TransitionActionObject = $Kernel::OM->Get('Kernel::System::ProcessManagement::DB::TransitionAction');
-
     # ------------------------------------------------------------ #
     # TransitionActionNew
     # ------------------------------------------------------------ #
@@ -77,9 +75,8 @@ sub Run {
         my $GetParam = $Self->_GetParams();
 
         # set new configuration
-        $TransitionActionData->{Name}             = $GetParam->{Name};
-        $TransitionActionData->{Config}->{Module} = $GetParam->{Module};
-        $TransitionActionData->{Config}->{Config} = $GetParam->{Config};
+        $TransitionActionData->{Name}   = $GetParam->{Name};
+        $TransitionActionData->{Config} = $GetParam->{Config};
 
         # check required parameters
         my %Error;
@@ -90,19 +87,33 @@ sub Run {
             $Error{NameServerErrorMessage} = Translatable('This field is required');
         }
 
-        if ( !$GetParam->{Module} ) {
+        if ( !$GetParam->{Config}->{Module} ) {
 
             # add server error error class
             $Error{ModuleServerError}        = 'ServerError';
             $Error{ModuleServerErrorMessage} = Translatable('This field is required');
         }
 
-        if ( !$GetParam->{Config} ) {
+        if ( !IsHashRefWithData( $GetParam->{Config}->{Config} ) ) {
             return $LayoutObject->ErrorScreen(
                 Message => Translatable('At least one valid config parameter is required.'),
             );
         }
 
+        if ( !$GetParam->{Config}->{Scope} ) {
+
+            # add server error error class
+            $Error{NameServerError}        = 'ServerError';
+            $Error{NameServerErrorMessage} = Translatable('This field is required');
+        }
+
+        if ( $GetParam->{Config}->{Scope} eq 'Process' && !$GetParam->{Config}->{ScopeEntityID} ) {
+
+            # add server error error class
+            $Error{NameServerError}        = 'ServerError';
+            $Error{NameServerErrorMessage} = Translatable('This field is required');
+        }
+
         # if there is an error return to edit screen
         if ( IsHashRefWithData( \%Error ) ) {
             return $Self->_ShowEdit(
@@ -129,7 +140,6 @@ sub Run {
         # otherwise save configuration and return process screen
         my $TransitionActionID = $TransitionActionObject->TransitionActionAdd(
             Name     => $TransitionActionData->{Name},
-            Module   => $TransitionActionData->{Module},
             EntityID => $EntityID,
             Config   => $TransitionActionData->{Config},
             UserID   => $Self->{UserID},
@@ -276,10 +286,9 @@ sub Run {
         my $GetParam = $Self->_GetParams();
 
         # set new configuration
-        $TransitionActionData->{Name}             = $GetParam->{Name};
-        $TransitionActionData->{EntityID}         = $GetParam->{EntityID};
-        $TransitionActionData->{Config}->{Module} = $GetParam->{Module};
-        $TransitionActionData->{Config}->{Config} = $GetParam->{Config};
+        $TransitionActionData->{Name}     = $GetParam->{Name};
+        $TransitionActionData->{EntityID} = $GetParam->{EntityID};
+        $TransitionActionData->{Config}   = $GetParam->{Config};
 
         # check required parameters
         my %Error;
@@ -290,19 +299,33 @@ sub Run {
             $Error{NameServerErrorMessage} = Translatable('This field is required');
         }
 
-        if ( !$GetParam->{Module} ) {
+        if ( !$GetParam->{Config}->{Module} ) {
 
             # add server error error class
             $Error{ModuleServerError}        = 'ServerError';
             $Error{ModuleServerErrorMessage} = Translatable('This field is required');
         }
 
-        if ( !$GetParam->{Config} ) {
+        if ( !$GetParam->{Config}->{Config} ) {
             return $LayoutObject->ErrorScreen(
                 Message => Translatable('At least one valid config parameter is required.'),
             );
         }
 
+        if ( !$GetParam->{Config}->{Scope} ) {
+
+            # add server error error class
+            $Error{NameServerError}        = 'ServerError';
+            $Error{NameServerErrorMessage} = Translatable('This field is required');
+        }
+
+        if ( $GetParam->{Config}->{Scope} eq 'Process' && !$GetParam->{Config}->{ScopeEntityID} ) {
+
+            # add server error error class
+            $Error{NameServerError}        = 'ServerError';
+            $Error{NameServerErrorMessage} = Translatable('This field is required');
+        }
+
         # if there is an error return to edit screen
         if ( IsHashRefWithData( \%Error ) ) {
             return $Self->_ShowEdit(
@@ -318,7 +341,6 @@ sub Run {
             ID       => $TransitionActionID,
             EntityID => $TransitionActionData->{EntityID},
             Name     => $TransitionActionData->{Name},
-            Module   => $TransitionActionData->{Module},
             Config   => $TransitionActionData->{Config},
             UserID   => $Self->{UserID},
         );
@@ -584,6 +606,35 @@ sub _ShowEdit {
         Class        => 'Modernize Validate_Required ' . ( $Param{Errors}->{'ModuleInvalid'} || '' ),
     );
 
+    $Param{ScopeSelection} = $LayoutObject->BuildSelection(
+        Data => {
+            Global  => 'Global',
+            Process => 'Current Process',
+        },
+        Name           => 'Scope',
+        ID             => 'Scope',
+        SelectedID     => $TransitionActionData->{Config}->{Scope} || 'Global',
+        Sort           => 'IndividualKey',
+        SortIndividual => [ 'Global', 'Process' ],
+        Translation    => 1,
+        Class          => 'Modernize W50pc ',
+    );
+
+    my $ProcessList = $Kernel::OM->Get('Kernel::System::ProcessManagement::DB::Process')->ProcessList(
+        UserID      => 1,
+        UseEntities => 1,
+    );
+
+    $Param{ScopeEntityIDSelection} = $LayoutObject->BuildSelection(
+        Data        => $ProcessList,
+        Name        => 'ScopeEntityID',
+        ID          => 'ScopeEntityID',
+        SelectedID  => $TransitionActionData->{Config}->{ScopeEntityID},
+        Sort        => 'AlphanumericKey',
+        Translation => 1,
+        Class       => 'Modernize W50pc ',
+    );
+
     $Output .= $LayoutObject->Output(
         TemplateFile => "AdminProcessManagementTransitionAction",
         Data         => {
@@ -605,13 +656,18 @@ sub _GetParams {
     my $ParamObject = $Kernel::OM->Get('Kernel::System::Web::Request');
 
     # get parameters from web browser
-    for my $ParamName (
-        qw( Name Module EntityID )
-        )
-    {
+    for my $ParamName (qw(Name EntityID)) {
         $GetParam->{$ParamName} = $ParamObject->GetParam( Param => $ParamName ) || '';
     }
 
+    for my $ParamName (qw(Module Scope ScopeEntityID)) {
+        $GetParam->{Config}->{$ParamName} = $ParamObject->GetParam( Param => $ParamName ) || '';
+    }
+    $GetParam->{Config}->{Scope} //= 'Global';
+    if ( $GetParam->{Config}->{Scope} eq 'Global' ) {
+        delete $GetParam->{Config}->{ScopeEntityID};
+    }
+
     # get config params
     my @ParamNames = $ParamObject->GetParamNames();
     my ( @ConfigParamKeys, @ConfigParamValues );
@@ -636,10 +692,13 @@ sub _GetParams {
     }
 
     my ( $KeyValue, $ValueValue );
+    PARAM:
     for my $Key (@ConfigParamKeys) {
         $KeyValue   = $ParamObject->GetParam( Param => "ConfigKey[$Key]" );
         $ValueValue = $ParamObject->GetParam( Param => "ConfigValue[$Key]" );
-        $GetParam->{Config}->{$KeyValue} = $ValueValue;
+
+        next PARAM if !$KeyValue || $KeyValue eq '';
+        $GetParam->{Config}->{Config}->{$KeyValue} = $ValueValue;
     }
 
     return $GetParam;
