@@ -1,7 +1,7 @@
 #!/usr/bin/env perl
 # --
 # Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
-# Copyright (C) 2021 Znuny GmbH, https://znuny.org/
+# Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
 # --
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -187,6 +187,16 @@ my @NeededModules = (
             ports  => 'archivers/p5-Archive-Zip',
         },
     },
+    {
+        Module    => 'Authen::SASL',
+        Required  => 1,
+        Comment   => 'Required for SASL authentication mechanisms (e.g. IMAP and SMTP connections).',
+        InstTypes => {
+            aptget => 'libauthen-sasl-perl',
+            emerge => 'dev-perl/Authen-SASL',
+            zypper => 'perl-Authen-SASL',
+        },
+    },
     {
         Module    => 'Crypt::Eksblowfish::Bcrypt',
         Required  => 0,
@@ -209,6 +219,18 @@ my @NeededModules = (
             ports  => 'converters/p5-CSS-Minifier-XS',
         },
     },
+    {
+        Module    => 'Data::UUID',
+        Required  => 1,
+        Comment   => 'Required to generate UUIDs.',
+        InstTypes => {
+            aptget => undef,
+            emerge => undef,
+            yum    => undef,
+            zypper => undef,
+            ports  => undef,
+        },
+    },
     {
         Module    => 'Date::Format',
         Required  => 1,
@@ -326,6 +348,30 @@ my @NeededModules = (
             ports  => 'chinese/p5-Encode-HanExtra',
         },
     },
+    {
+        Module          => 'Excel::Writer::XLSX',
+        VersionRequired => '0.95',
+        Required        => 0,
+        Comment         => 'Required for the creation of Excel statistical reports.',
+        InstTypes       => {
+            aptget => 'libexcel-writer-xlsx-perl',
+            emerge => 'dev-perl/Excel-Writer-XLSX',
+            zypper => 'perl-Excel-Writer-XLSX',
+            ports  => 'textproc/p5-Excel-Writer-XLSX',
+        },
+    },
+    {
+        Module          => 'Hash::Merge',
+        VersionRequired => '0.300',
+        Required        => 0,
+        Comment         => 'Required for the creation of Excel statistical reports.',
+        InstTypes       => {
+            aptget => 'libhash-merge-perl',
+            emerge => 'dev-perl/Hash-Merge',
+            zypper => 'perl-Hash-Merge',
+            ports  => 'textproc/p5-Hash-Merge',
+        },
+    },
     {
         Module              => 'IO::Socket::SSL',
         Required            => 0,
@@ -429,16 +475,6 @@ my @NeededModules = (
                     ports  => 'security/p5-IO-Socket-SSL',
                 },
             },
-            {
-                Module    => 'Authen::SASL',
-                Required  => 0,
-                Comment   => 'Required for MD5 authentication mechanisms in IMAP connections.',
-                InstTypes => {
-                    aptget => 'libauthen-sasl-perl',
-                    emerge => 'dev-perl/Authen-SASL',
-                    zypper => 'perl-Authen-SASL',
-                },
-            },
             {
                 Module    => 'Authen::NTLM',
                 Required  => 0,
@@ -521,7 +557,7 @@ my @NeededModules = (
     {
         Module    => 'Spreadsheet::XLSX',
         Required  => 0,
-        Comment   => 'Spreadsheet::XLSX enables import of Excel files in certain dialogs.',
+        Comment   => 'Spreadsheet::XLSX enables import and export of Excel files in certain dialogs.',
         InstTypes => {
             aptget => 'libspreadsheet-xlsx-perl',
             emerge => 'dev-perl/Spreadsheet-XLSX',
